==> igniteui-webcomponents-core-3.2.4.tgz: package/esm5/lib/RadialPieSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnchoredRadialSeriesDescriptionMetadata } from "./AnchoredRadialSeriesDescriptionMetadata";
import { RadialPieSeriesDescription } from "./RadialPieSeriesDescription";
/**
 * @hidden
 */
var RadialPieSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(RadialPieSeriesDescriptionMetadata, _super);
    function RadialPieSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RadialPieSeriesDescriptionMetadata.b = function (a) {
        if (RadialPieSeriesDescriptionMetadata.a == null) {
            RadialPieSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            RadialPieSeriesDescriptionMetadata.c(RadialPieSeriesDescriptionMetadata.a);
        }
        if (a.g(RadialPieSeriesDescriptionMetadata.a)) {
            return;
        }
        a.s(RadialPieSeriesDescriptionMetadata.a);
    };
    RadialPieSeriesDescriptionMetadata.c = function (a) {
        AnchoredRadialSeriesDescriptionMetadata.c(a);
        a.item("RadiusX", "Number:double");
        a.item("RadiusY", "Number:double");
    };
    RadialPieSeriesDescriptionMetadata.d = function (a) {
        RadialPieSeriesDescriptionMetadata.b(a);
        a.u("RadialPieSeries", function () { return new RadialPieSeriesDescription(); });
        a.t("RadialPieSeries", RadialPieSeriesDescriptionMetadata.a);
    };
    RadialPieSeriesDescriptionMetadata.$t = markType(RadialPieSeriesDescriptionMetadata, 'RadialPieSeriesDescriptionMetadata');
    RadialPieSeriesDescriptionMetadata.a = null;
    return RadialPieSeriesDescriptionMetadata;
}(Base));
export { RadialPieSeriesDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/RadialPieSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnchoredRadialSeriesDescriptionMetadata } from "./AnchoredRadialSeriesDescriptionMetadata";
import { RadialPieSeriesDescription } from "./RadialPieSeriesDescription";
/**
 * @hidden
 */
var RadialPieSeriesDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(RadialPieSeriesDescriptionMetadata, _super);
    function RadialPieSeriesDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RadialPieSeriesDescriptionMetadata.b = function (a) {
        if (RadialPieSeriesDescriptionMetadata.a == null) {
            RadialPieSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            RadialPieSeriesDescriptionMetadata.c(RadialPieSeriesDescriptionMetadata.a);
        }
        if (a.j(RadialPieSeriesDescriptionMetadata.a)) {
            return;
        }
        a.y(RadialPieSeriesDescriptionMetadata.a);
    };
    RadialPieSeriesDescriptionMetadata.c = function (a) {
        AnchoredRadialSeriesDescriptionMetadata.c(a);
        a.item("RadiusX", "Number:double");
        a.item("RadiusY", "Number:double");
    };
    RadialPieSeriesDescriptionMetadata.d = function (a) {
        RadialPieSeriesDescriptionMetadata.b(a);
        a.aa("RadialPieSeries", function () { return new RadialPieSeriesDescription(); });
        a.z("RadialPieSeries", RadialPieSeriesDescriptionMetadata.a);
    };
    RadialPieSeriesDescriptionMetadata.$t = markType(RadialPieSeriesDescriptionMetadata, 'RadialPieSeriesDescriptionMetadata');
    RadialPieSeriesDescriptionMetadata.a = null;
    return RadialPieSeriesDescriptionMetadata;
}(Base));
export { RadialPieSeriesDescriptionMetadata };
